% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DechallengeRechallenge.R
\name{computeRechallengeFailCaseSeriesAnalyses}
\alias{computeRechallengeFailCaseSeriesAnalyses}
\title{Compute fine the subjects that fail the dechallenge rechallenge study}
\usage{
computeRechallengeFailCaseSeriesAnalyses(
  connectionDetails = NULL,
  targetDatabaseSchema,
  targetTable,
  outcomeDatabaseSchema = targetDatabaseSchema,
  outcomeTable = targetTable,
  tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
  settings,
  databaseId = "database 1",
  showSubjectId = FALSE,
  outputFolder,
  minCellCount = 0,
  ...
)
}
\arguments{
\item{connectionDetails}{An object of type `connectionDetails` as created using the
[DatabaseConnector::createConnectionDetails()] function.}

\item{targetDatabaseSchema}{Schema name where your target cohort table resides. Note that for SQL Server,
this should include both the database and schema name, for example
'scratch.dbo'.}

\item{targetTable}{Name of the target cohort table.}

\item{outcomeDatabaseSchema}{Schema name where your outcome cohort table resides. Note that for SQL Server,
this should include both the database and schema name, for example
'scratch.dbo'.}

\item{outcomeTable}{Name of the outcome cohort table.}

\item{tempEmulationSchema}{Some database platforms like Oracle and Impala do not truly support temp tables.
To emulate temp tables, provide a schema with write privileges where temp tables
can be created}

\item{settings}{The settings for the timeToEvent study}

\item{databaseId}{An identifier for the database (string)}

\item{showSubjectId}{if F then subject_ids are hidden (recommended if sharing results)}

\item{outputFolder}{A directory to save the results as csv files}

\item{minCellCount}{The minimum cell value to display, values less than this will be replaced by -1}

\item{...}{extra inputs}
}
\value{
An \code{Andromeda::andromeda()} object with the case series details of the failed rechallenge
}
\description{
Compute fine the subjects that fail the dechallenge rechallenge study
}
\examples{

conDet <- exampleOmopConnectionDetails()

drSet <- createDechallengeRechallengeSettings(
  targetIds = c(1,2),
  outcomeIds = 3
)

computeRechallengeFailCaseSeriesAnalyses(
  connectionDetails = conDet,
  targetDatabaseSchema = 'main',
  targetTable = 'cohort',
  settings = drSet,
  outputFolder = tempdir()
)

}
\seealso{
Other DechallengeRechallenge: 
\code{\link{computeDechallengeRechallengeAnalyses}()},
\code{\link{createDechallengeRechallengeSettings}()}
}
\concept{DechallengeRechallenge}
